==> jangaroo-sdk-0.9.3.zip: joo/classes/flashx/textLayout/events/StatusChangeEvent.js <==
joo.classLoader.prepare("package flashx.textLayout.events",/* {
import flash.events.ErrorEvent;
import flash.events.Event;

import flashx.textLayout.elements.FlowElement;*/

/**
 * A TextFlow instance dispatches this event when the status of a FlowElement changes. This event can be used to detect when an inline graphic element has completed loading. You can use your event handler to recompose the text flow based on the presence of the newly loaded inline graphic element.
 * <p><a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/flashx/textLayout/events/StatusChangeEvent.html#includeExamplesSummary">View the examples</a></p>
 */
"public class StatusChangeEvent extends flash.events.Event",2,function($$private){;return[ 
  /**
   * The FlowElement instance that has experienced a change in status.
   * @see flashx.textLayout.elements.FlowElement
   *
   */
  "public function get element",function element$get()/*:FlowElement*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set element",function element$set(value/*:FlowElement*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * The ErrorEvent object that was dispatched as a result of the status change.
   * @see flash.events.ErrorEvent
   *
   */
  "public function get errorEvent",function errorEvent$get()/*:ErrorEvent*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set errorEvent",function errorEvent$set(value/*:ErrorEvent*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * The FlowElement's new status. The possible values of this property are defined by the InlineGraphicElementStatus class. There are five static constants available in the InlineGraphicElementStatus class:
   * <ul>
   * <li>ERROR : String = "error". An error occurred during loading of a referenced graphic.</li>
   * <li>LOADING : String = "loading". Load has been initiated (but not completed) on a graphic element that is a URL.</li>
   * <li>LOAD_PENDING : String = "loadPending". Graphic element is an URL that has not been loaded.</li>
   * <li>READY : String = "ready". Graphic is completely loaded and properly sized.</li>
   * <li>SIZE_PENDING : String = "sizePending". Graphic element with auto or percentage width/height has completed loading but has not been recomposed.</li></ul>
   * @see flashx.textLayout.elements.InlineGraphicElementStatus
   *
   */
  "public function get status",function status$get()/*:String*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set status",function status$set(value/*:String*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Creates an event object that contains information about a status change.
   * @param type The type of the event. Event listeners can access this information through the inherited <code>type</code> property. There is only one type of StatusChangeEvent: <code>StatusChangeEvent.INLINE_GRAPHIC_STATUS_CHANGE</code>;
   * @param bubbles Indicates whether an event is a bubbling event.This event does not bubble.
   * @param cancelable Indicates whether the behavior associated with the event can be prevented. This event cannot be cancelled.
   * @param element The FlowElement instance that has experienced a change in status.
   * @param status The FlowElement instance's new status.
   * @param errorEvent The ErrorEvent object, if any, associated with the status.
   *
   */
  "public function StatusChangeEvent",function StatusChangeEvent$(type/*:String*/, bubbles/*:Boolean = false*/, cancelable/*:Boolean = false*/, element/*:FlowElement = null*/, status/*:String = null*/, errorEvent/*:ErrorEvent = null*/) {flash.events.Event.call(this);if(arguments.length<6){if(arguments.length<5){if(arguments.length<4){if(arguments.length<3){if(arguments.length<2){bubbles = false;}cancelable = false;}element = null;}status = null;}errorEvent = null;}
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Defines the value of the <code>type</code> property of a <code>inlineGraphicStatusChanged</code> event object.
   */
  "public static const",{ INLINE_GRAPHIC_STATUS_CHANGE/*:String*/ : "inlineGraphicStatusChange"},
];},[],["flash.events.Event","Error"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/flashx/textLayout/events/StatusChangeEvent.js <==
joo.classLoader.prepare("package flashx.textLayout.events",/* {
import flash.events.ErrorEvent;
import flash.events.Event;

import flashx.textLayout.elements.FlowElement;*/

/**
 * A TextFlow instance dispatches this event when the status of a FlowElement changes. This event can be used to detect when an inline graphic element has completed loading. You can use your event handler to recompose the text flow based on the presence of the newly loaded inline graphic element.
 * <p><a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/flashx/textLayout/events/StatusChangeEvent.html#includeExamplesSummary">View the examples</a></p>
 */
"public class StatusChangeEvent extends flash.events.Event",2,function($$private){var $1=flash.events;return[ 
  /**
   * The FlowElement instance that has experienced a change in status.
   * @see flashx.textLayout.elements.FlowElement
   *
   */
  "public function get element",function element$get()/*:FlowElement*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set element",function element$set(value/*:FlowElement*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * The ErrorEvent object that was dispatched as a result of the status change.
   * @see flash.events.ErrorEvent
   *
   */
  "public function get errorEvent",function errorEvent$get()/*:ErrorEvent*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set errorEvent",function errorEvent$set(value/*:ErrorEvent*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * The FlowElement's new status. The possible values of this property are defined by the InlineGraphicElementStatus class. There are five static constants available in the InlineGraphicElementStatus class:
   * <ul>
   * <li>ERROR : String = "error". An error occurred during loading of a referenced graphic.</li>
   * <li>LOADING : String = "loading". Load has been initiated (but not completed) on a graphic element that is a URL.</li>
   * <li>LOAD_PENDING : String = "loadPending". Graphic element is an URL that has not been loaded.</li>
   * <li>READY : String = "ready". Graphic is completely loaded and properly sized.</li>
   * <li>SIZE_PENDING : String = "sizePending". Graphic element with auto or percentage width/height has completed loading but has not been recomposed.</li></ul>
   * @see flashx.textLayout.elements.InlineGraphicElementStatus
   *
   */
  "public function get status",function status$get()/*:String*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set status",function status$set(value/*:String*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Creates an event object that contains information about a status change.
   * @param type The type of the event. Event listeners can access this information through the inherited <code>type</code> property. There is only one type of StatusChangeEvent: <code>StatusChangeEvent.INLINE_GRAPHIC_STATUS_CHANGE</code>;
   * @param bubbles Indicates whether an event is a bubbling event.This event does not bubble.
   * @param cancelable Indicates whether the behavior associated with the event can be prevented. This event cannot be cancelled.
   * @param element The FlowElement instance that has experienced a change in status.
   * @param status The FlowElement instance's new status.
   * @param errorEvent The ErrorEvent object, if any, associated with the status.
   *
   */
  "public function StatusChangeEvent",function StatusChangeEvent(type/*:String*/, bubbles/*:Boolean = false*/, cancelable/*:Boolean = false*/, element/*:FlowElement = null*/, status/*:String = null*/, errorEvent/*:ErrorEvent = null*/) { $1.Event.call(this);switch(Math.max(arguments.length,1)){case 1:bubbles=false;case 2:cancelable=false;case 3:element=null;case 4:status=null;case 5:errorEvent=null;}
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Defines the value of the <code>type</code> property of a <code>inlineGraphicStatusChanged</code> event object.
   */
  "public static const",{ INLINE_GRAPHIC_STATUS_CHANGE/*:String*/ : "inlineGraphicStatusChange"},
undefined];},[],["flash.events.Event","Error"], "0.8.0", "0.9.12"
);
